# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetAthlete(BaseModel):
    get_athlete: Optional["GetAthleteGetAthlete"] = Field(alias="getAthlete")


class GetAthleteGetAthlete(BaseModel):
    id: Optional[int]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    friendly_name: Optional[str] = Field(alias="friendlyName")
    full_name: Optional[str] = Field(alias="fullName")
    friendly_name_letter: Optional[str] = Field(alias="friendlyNameLetter")
    friendly_name_first3_letter: Optional[str] = Field(alias="friendlyNameFirst3Letter")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    birth_date: Optional[str] = Field(alias="birthDate")
    birth_place: Optional[str] = Field(alias="birthPlace")
    birth_place_country_name: Optional[str] = Field(alias="birthPlaceCountryName")
    sex_name_url_slug: Optional[str] = Field(alias="sexNameUrlSlug")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    birth_place_country_url_slug: Optional[str] = Field(
        alias="birthPlaceCountryUrlSlug"
    )
    birth_country_code: Optional[str] = Field(alias="birthCountryCode")
    primary_media_id: Optional[str] = Field(alias="primaryMediaId")
    primary_media_edited: Optional[str] = Field(alias="primaryMediaEdited")
    primary_media: Optional[List[Optional["GetAthleteGetAthletePrimaryMedia"]]] = Field(
        alias="primaryMedia"
    )
    url_slug: Optional[str] = Field(alias="urlSlug")
    representative_id: Optional[int] = Field(alias="representativeId")
    biography: Optional[str]
    twitter_link: Optional[str] = Field(alias="twitterLink")
    instagram_link: Optional[str] = Field(alias="instagramLink")
    facebook_link: Optional[str] = Field(alias="facebookLink")
    transfers_of_allegiance: Optional[List[Optional[str]]] = Field(
        alias="transfersOfAllegiance"
    )
    aa_id: Optional[int] = Field(alias="aaId")
    country_full_name: Optional[str] = Field(alias="countryFullName")
    family_name: Optional[str] = Field(alias="familyName")
    given_name: Optional[str] = Field(alias="givenName")
    birth_date_str: Optional[str] = Field(alias="birthDateStr")
    facebook_username: Optional[str] = Field(alias="facebookUsername")
    twitter_username: Optional[str] = Field(alias="twitterUsername")
    instagram_username: Optional[str] = Field(alias="instagramUsername")
    media_ids: Optional[List[Optional[str]]] = Field(alias="mediaIds")


class GetAthleteGetAthletePrimaryMedia(BaseModel):
    id: Optional[str]
    title: Optional[str]
    s_e_o_title: Optional[str] = Field(alias="sEOTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    credit: Optional[str]
    show_in_media: Optional[bool] = Field(alias="showInMedia")
    complete: Optional[bool]
    file_name: Optional[str] = Field(alias="fileName")
    remote_item_code: Optional[str] = Field(alias="remoteItemCode")
    x_m_l_file_name360: Optional[str] = Field(alias="xMLFileName360")
    file_name_url: Optional[str] = Field(alias="fileNameUrl")
    type: Optional[int]
    format: Optional[int]
    hosting: Optional[int]
    related_links: Optional[List[Optional[str]]] = Field(alias="relatedLinks")
    source_width: Optional[int] = Field(alias="sourceWidth")
    source_height: Optional[int] = Field(alias="sourceHeight")
    available_ratios: Optional[List[Optional[int]]] = Field(alias="availableRatios")
    related_sex_codes: Optional[List[Optional[int]]] = Field(alias="relatedSexCodes")
    related_age_groups: Optional[List[Optional[int]]] = Field(alias="relatedAgeGroups")
    related_event_phases: Optional[List[Optional[int]]] = Field(
        alias="relatedEventPhases"
    )
    status: Optional[int]
    live_from: Optional[Any] = Field(alias="liveFrom")
    created_on: Optional[str] = Field(alias="createdOn")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    created_by_id: Optional[str] = Field(alias="createdById")
    updated_by_id: Optional[str] = Field(alias="updatedById")


GetAthlete.update_forward_refs()
GetAthleteGetAthlete.update_forward_refs()
GetAthleteGetAthletePrimaryMedia.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetAssetsTotal(BaseModel):
    get_assets_total: Optional["GetAssetsTotalGetAssetsTotal"] = Field(
        alias="getAssetsTotal"
    )


class GetAssetsTotalGetAssetsTotal(BaseModel):
    total: Optional[str]


GetAssetsTotal.update_forward_refs()
GetAssetsTotalGetAssetsTotal.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCountries(BaseModel):
    get_countries: Optional[List[Optional["GetCountriesGetCountries"]]] = Field(
        alias="getCountries"
    )


class GetCountriesGetCountries(BaseModel):
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    id: Optional[str]
    country_name: Optional[str] = Field(alias="countryName")
    country_order: Optional[int] = Field(alias="countryOrder")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    area_order: Optional[int] = Field(alias="areaOrder")
    is_valid: Optional[bool] = Field(alias="isValid")
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    country_name_url_slug: Optional[str] = Field(alias="countryNameUrlSlug")


GetCountries.update_forward_refs()
GetCountriesGetCountries.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetAssetsDates(BaseModel):
    get_assets_dates: Optional["GetAssetsDatesGetAssetsDates"] = Field(
        alias="getAssetsDates"
    )


class GetAssetsDatesGetAssetsDates(BaseModel):
    dates: Optional[List[Optional[Any]]]


GetAssetsDates.update_forward_refs()
GetAssetsDatesGetAssetsDates.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class CurrentRecordHolder(BaseModel):
    current_record_holder: Optional[
        List[Optional["CurrentRecordHolderCurrentRecordHolder"]]
    ] = Field(alias="currentRecordHolder")


class CurrentRecordHolderCurrentRecordHolder(BaseModel):
    progression_list_id: Optional[int] = Field(alias="progressionListId")
    category: Optional[str]
    performance: Optional[str]
    equal: Optional[bool]
    pending: Optional[bool]
    set_indoor: Optional[bool] = Field(alias="setIndoor")
    women_only: Optional[bool] = Field(alias="womenOnly")
    mixed: Optional[bool]
    yard: Optional[bool]
    wind: Optional[str]
    competitor: Optional["CurrentRecordHolderCurrentRecordHolderCompetitor"]
    country: Optional[str]
    venue: Optional[str]
    date: Optional[str]
    legend: Optional[str]
    discipline: Optional[str]
    discipline_name_url_slug: Optional[str] = Field(alias="disciplineNameUrlSlug")


class CurrentRecordHolderCurrentRecordHolderCompetitor(BaseModel):
    name: Optional[str]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    url_slug: Optional[str] = Field(alias="urlSlug")
    birth_date: Optional[str] = Field(alias="birthDate")


CurrentRecordHolder.update_forward_refs()
CurrentRecordHolderCurrentRecordHolder.update_forward_refs()
CurrentRecordHolderCurrentRecordHolderCompetitor.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetArticle(BaseModel):
    get_article: Optional["GetArticleGetArticle"] = Field(alias="getArticle")


class GetArticleGetArticle(BaseModel):
    id: Optional[str]
    title: Optional[str]
    location: Optional["GetArticleGetArticleLocation"]
    body: Optional[str]
    stand_first: Optional[str] = Field(alias="standFirst")
    meta_description: Optional[str] = Field(alias="metaDescription")
    s_e_o_title: Optional[str] = Field(alias="sEOTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    plain_text_body: Optional[str] = Field(alias="plainTextBody")
    author_ids: Optional[List[Optional[str]]] = Field(alias="authorIds")
    competitor_author_id: Optional[int] = Field(alias="competitorAuthorId")
    article_type: Optional[int] = Field(alias="articleType")
    featured: Optional[bool]
    featured_order: Optional[int] = Field(alias="featuredOrder")
    status: Optional[int]
    live_from: Optional[Any] = Field(alias="liveFrom")
    created_on: Optional[Any] = Field(alias="createdOn")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    live_from_day: Optional[int] = Field(alias="liveFromDay")
    live_from_month: Optional[int] = Field(alias="liveFromMonth")
    live_from_year: Optional[int] = Field(alias="liveFromYear")
    related_media: Optional[List[Optional["GetArticleGetArticleRelatedMedia"]]] = Field(
        alias="relatedMedia"
    )
    related_media_ids: Optional[List[Optional[str]]] = Field(alias="relatedMediaIds")
    related_articles: Optional[
        List[Optional["GetArticleGetArticleRelatedArticles"]]
    ] = Field(alias="relatedArticles")
    related_article_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedArticleIds"
    )
    related_discipline: Optional[
        List[Optional["GetArticleGetArticleRelatedDiscipline"]]
    ] = Field(alias="relatedDiscipline")
    related_discipline_codes: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplineCodes"
    )
    related_competitors: Optional[
        List[Optional["GetArticleGetArticleRelatedCompetitors"]]
    ] = Field(alias="relatedCompetitors")
    related_competitor_ids: Optional[List[Optional[int]]] = Field(
        alias="relatedCompetitorIds"
    )
    related_competitions: Optional[
        List[Optional["GetArticleGetArticleRelatedCompetitions"]]
    ] = Field(alias="relatedCompetitions")
    related_competition_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitionIds"
    )
    related_discipline_type_name_urls_slugs: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplineTypeNameUrlsSlugs"
    )
    related_event_ids: Optional[List[Optional[int]]] = Field(alias="relatedEventIds")
    related_links: Optional[List[Optional[str]]] = Field(alias="relatedLinks")
    related_document_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedDocumentIds"
    )
    related_spikes_article_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedSpikesArticleIds"
    )
    related_minisite_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedMinisiteIds"
    )
    tags: Optional[List[Optional[str]]]
    gated_content: Optional[bool] = Field(alias="gatedContent")


class GetArticleGetArticleLocation(BaseModel):
    name: Optional[str]


class GetArticleGetArticleRelatedMedia(BaseModel):
    id: Optional[str]
    title: Optional[str]
    s_e_o_title: Optional[str] = Field(alias="sEOTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    credit: Optional[str]
    show_in_media: Optional[bool] = Field(alias="showInMedia")
    complete: Optional[bool]
    file_name: Optional[str] = Field(alias="fileName")
    remote_item_code: Optional[str] = Field(alias="remoteItemCode")
    x_m_l_file_name360: Optional[str] = Field(alias="xMLFileName360")
    file_name_url: Optional[str] = Field(alias="fileNameUrl")
    type: Optional[int]
    format: Optional[int]
    hosting: Optional[int]
    related_links: Optional[List[Optional[str]]] = Field(alias="relatedLinks")
    source_width: Optional[int] = Field(alias="sourceWidth")
    source_height: Optional[int] = Field(alias="sourceHeight")
    available_ratios: Optional[List[Optional[int]]] = Field(alias="availableRatios")
    related_sex_codes: Optional[List[Optional[int]]] = Field(alias="relatedSexCodes")
    related_age_groups: Optional[List[Optional[int]]] = Field(alias="relatedAgeGroups")
    related_event_phases: Optional[List[Optional[int]]] = Field(
        alias="relatedEventPhases"
    )
    status: Optional[int]
    live_from: Optional[Any] = Field(alias="liveFrom")
    created_on: Optional[str] = Field(alias="createdOn")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    created_by_id: Optional[str] = Field(alias="createdById")
    updated_by_id: Optional[str] = Field(alias="updatedById")


class GetArticleGetArticleRelatedArticles(BaseModel):
    id: Optional[str]
    title: Optional[str]
    location: Optional["GetArticleGetArticleRelatedArticlesLocation"]
    body: Optional[str]
    stand_first: Optional[str] = Field(alias="standFirst")
    meta_description: Optional[str] = Field(alias="metaDescription")
    s_e_o_title: Optional[str] = Field(alias="sEOTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    plain_text_body: Optional[str] = Field(alias="plainTextBody")
    author_ids: Optional[List[Optional[str]]] = Field(alias="authorIds")
    competitor_author_id: Optional[int] = Field(alias="competitorAuthorId")
    article_type: Optional[int] = Field(alias="articleType")
    featured: Optional[bool]
    featured_order: Optional[int] = Field(alias="featuredOrder")
    status: Optional[int]
    live_from: Optional[Any] = Field(alias="liveFrom")
    created_on: Optional[Any] = Field(alias="createdOn")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    live_from_day: Optional[int] = Field(alias="liveFromDay")
    live_from_month: Optional[int] = Field(alias="liveFromMonth")
    live_from_year: Optional[int] = Field(alias="liveFromYear")
    related_media: Optional[
        List[Optional["GetArticleGetArticleRelatedArticlesRelatedMedia"]]
    ] = Field(alias="relatedMedia")
    related_media_ids: Optional[List[Optional[str]]] = Field(alias="relatedMediaIds")
    related_articles: Optional[
        List[Optional["GetArticleGetArticleRelatedArticlesRelatedArticles"]]
    ] = Field(alias="relatedArticles")
    related_article_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedArticleIds"
    )
    related_discipline: Optional[
        List[Optional["GetArticleGetArticleRelatedArticlesRelatedDiscipline"]]
    ] = Field(alias="relatedDiscipline")
    related_discipline_codes: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplineCodes"
    )
    related_competitors: Optional[
        List[Optional["GetArticleGetArticleRelatedArticlesRelatedCompetitors"]]
    ] = Field(alias="relatedCompetitors")
    related_competitor_ids: Optional[List[Optional[int]]] = Field(
        alias="relatedCompetitorIds"
    )
    related_competitions: Optional[
        List[Optional["GetArticleGetArticleRelatedArticlesRelatedCompetitions"]]
    ] = Field(alias="relatedCompetitions")
    related_competition_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitionIds"
    )
    related_discipline_type_name_urls_slugs: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplineTypeNameUrlsSlugs"
    )
    related_event_ids: Optional[List[Optional[int]]] = Field(alias="relatedEventIds")
    related_links: Optional[List[Optional[str]]] = Field(alias="relatedLinks")
    related_document_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedDocumentIds"
    )
    related_spikes_article_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedSpikesArticleIds"
    )
    related_minisite_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedMinisiteIds"
    )
    tags: Optional[List[Optional[str]]]
    gated_content: Optional[bool] = Field(alias="gatedContent")


class GetArticleGetArticleRelatedArticlesLocation(BaseModel):
    name: Optional[str]


class GetArticleGetArticleRelatedArticlesRelatedMedia(BaseModel):
    id: Optional[str]
    title: Optional[str]
    s_e_o_title: Optional[str] = Field(alias="sEOTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    credit: Optional[str]
    show_in_media: Optional[bool] = Field(alias="showInMedia")
    complete: Optional[bool]
    file_name: Optional[str] = Field(alias="fileName")
    remote_item_code: Optional[str] = Field(alias="remoteItemCode")
    x_m_l_file_name360: Optional[str] = Field(alias="xMLFileName360")
    file_name_url: Optional[str] = Field(alias="fileNameUrl")
    type: Optional[int]
    format: Optional[int]
    hosting: Optional[int]
    related_links: Optional[List[Optional[str]]] = Field(alias="relatedLinks")
    source_width: Optional[int] = Field(alias="sourceWidth")
    source_height: Optional[int] = Field(alias="sourceHeight")
    available_ratios: Optional[List[Optional[int]]] = Field(alias="availableRatios")
    related_sex_codes: Optional[List[Optional[int]]] = Field(alias="relatedSexCodes")
    related_age_groups: Optional[List[Optional[int]]] = Field(alias="relatedAgeGroups")
    related_event_phases: Optional[List[Optional[int]]] = Field(
        alias="relatedEventPhases"
    )
    status: Optional[int]
    live_from: Optional[Any] = Field(alias="liveFrom")
    created_on: Optional[str] = Field(alias="createdOn")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    created_by_id: Optional[str] = Field(alias="createdById")
    updated_by_id: Optional[str] = Field(alias="updatedById")


class GetArticleGetArticleRelatedArticlesRelatedArticles(BaseModel):
    id: Optional[str]
    title: Optional[str]
    location: Optional["GetArticleGetArticleRelatedArticlesRelatedArticlesLocation"]
    body: Optional[str]
    stand_first: Optional[str] = Field(alias="standFirst")
    meta_description: Optional[str] = Field(alias="metaDescription")
    s_e_o_title: Optional[str] = Field(alias="sEOTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    plain_text_body: Optional[str] = Field(alias="plainTextBody")
    author_ids: Optional[List[Optional[str]]] = Field(alias="authorIds")
    competitor_author_id: Optional[int] = Field(alias="competitorAuthorId")
    article_type: Optional[int] = Field(alias="articleType")
    featured: Optional[bool]
    featured_order: Optional[int] = Field(alias="featuredOrder")
    status: Optional[int]
    live_from: Optional[Any] = Field(alias="liveFrom")
    created_on: Optional[Any] = Field(alias="createdOn")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    live_from_day: Optional[int] = Field(alias="liveFromDay")
    live_from_month: Optional[int] = Field(alias="liveFromMonth")
    live_from_year: Optional[int] = Field(alias="liveFromYear")
    related_media: Optional[
        List[Optional["GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedMedia"]]
    ] = Field(alias="relatedMedia")
    related_media_ids: Optional[List[Optional[str]]] = Field(alias="relatedMediaIds")
    related_articles: Optional[
        List[
            Optional[
                "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticles"
            ]
        ]
    ] = Field(alias="relatedArticles")
    related_article_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedArticleIds"
    )
    related_discipline: Optional[
        List[
            Optional[
                "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedDiscipline"
            ]
        ]
    ] = Field(alias="relatedDiscipline")
    related_discipline_codes: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplineCodes"
    )
    related_competitors: Optional[
        List[
            Optional[
                "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitors"
            ]
        ]
    ] = Field(alias="relatedCompetitors")
    related_competitor_ids: Optional[List[Optional[int]]] = Field(
        alias="relatedCompetitorIds"
    )
    related_competitions: Optional[
        List[
            Optional[
                "GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitions"
            ]
        ]
    ] = Field(alias="relatedCompetitions")
    related_competition_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitionIds"
    )
    related_discipline_type_name_urls_slugs: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplineTypeNameUrlsSlugs"
    )
    related_event_ids: Optional[List[Optional[int]]] = Field(alias="relatedEventIds")
    related_links: Optional[List[Optional[str]]] = Field(alias="relatedLinks")
    related_document_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedDocumentIds"
    )
    related_spikes_article_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedSpikesArticleIds"
    )
    related_minisite_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedMinisiteIds"
    )
    tags: Optional[List[Optional[str]]]
    gated_content: Optional[bool] = Field(alias="gatedContent")


class GetArticleGetArticleRelatedArticlesRelatedArticlesLocation(BaseModel):
    name: Optional[str]


class GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedMedia(BaseModel):
    id: Optional[str]
    title: Optional[str]
    s_e_o_title: Optional[str] = Field(alias="sEOTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    credit: Optional[str]
    show_in_media: Optional[bool] = Field(alias="showInMedia")
    complete: Optional[bool]
    file_name: Optional[str] = Field(alias="fileName")
    remote_item_code: Optional[str] = Field(alias="remoteItemCode")
    x_m_l_file_name360: Optional[str] = Field(alias="xMLFileName360")
    file_name_url: Optional[str] = Field(alias="fileNameUrl")
    type: Optional[int]
    format: Optional[int]
    hosting: Optional[int]
    related_links: Optional[List[Optional[str]]] = Field(alias="relatedLinks")
    source_width: Optional[int] = Field(alias="sourceWidth")
    source_height: Optional[int] = Field(alias="sourceHeight")
    available_ratios: Optional[List[Optional[int]]] = Field(alias="availableRatios")
    related_sex_codes: Optional[List[Optional[int]]] = Field(alias="relatedSexCodes")
    related_age_groups: Optional[List[Optional[int]]] = Field(alias="relatedAgeGroups")
    related_event_phases: Optional[List[Optional[int]]] = Field(
        alias="relatedEventPhases"
    )
    status: Optional[int]
    live_from: Optional[Any] = Field(alias="liveFrom")
    created_on: Optional[str] = Field(alias="createdOn")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    created_by_id: Optional[str] = Field(alias="createdById")
    updated_by_id: Optional[str] = Field(alias="updatedById")


class GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticles(BaseModel):
    id: Optional[str]
    title: Optional[str]
    body: Optional[str]
    stand_first: Optional[str] = Field(alias="standFirst")
    meta_description: Optional[str] = Field(alias="metaDescription")
    s_e_o_title: Optional[str] = Field(alias="sEOTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    plain_text_body: Optional[str] = Field(alias="plainTextBody")
    author_ids: Optional[List[Optional[str]]] = Field(alias="authorIds")
    competitor_author_id: Optional[int] = Field(alias="competitorAuthorId")
    article_type: Optional[int] = Field(alias="articleType")
    featured: Optional[bool]
    featured_order: Optional[int] = Field(alias="featuredOrder")
    status: Optional[int]
    live_from: Optional[Any] = Field(alias="liveFrom")
    created_on: Optional[Any] = Field(alias="createdOn")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    live_from_day: Optional[int] = Field(alias="liveFromDay")
    live_from_month: Optional[int] = Field(alias="liveFromMonth")
    live_from_year: Optional[int] = Field(alias="liveFromYear")
    related_media_ids: Optional[List[Optional[str]]] = Field(alias="relatedMediaIds")
    related_article_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedArticleIds"
    )
    related_discipline_codes: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplineCodes"
    )
    related_competitor_ids: Optional[List[Optional[int]]] = Field(
        alias="relatedCompetitorIds"
    )
    related_competition_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitionIds"
    )
    related_discipline_type_name_urls_slugs: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplineTypeNameUrlsSlugs"
    )
    related_event_ids: Optional[List[Optional[int]]] = Field(alias="relatedEventIds")
    related_links: Optional[List[Optional[str]]] = Field(alias="relatedLinks")
    related_document_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedDocumentIds"
    )
    related_spikes_article_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedSpikesArticleIds"
    )
    related_minisite_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedMinisiteIds"
    )
    tags: Optional[List[Optional[str]]]
    gated_content: Optional[bool] = Field(alias="gatedContent")


class GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedDiscipline(BaseModel):
    id: Optional[str]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    name: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    type_name: Optional[str] = Field(alias="typeName")
    type_order: Optional[int] = Field(alias="typeOrder")
    order: Optional[int]
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_road: Optional[bool] = Field(alias="isRoad")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")


class GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitors(BaseModel):
    id: Optional[int]
    media_ids: Optional[List[Optional[int]]] = Field(alias="mediaIds")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    birth_date_str: Optional[str] = Field(alias="birthDateStr")
    url_slug: Optional[str] = Field(alias="urlSlug")
    representative_id: Optional[int] = Field(alias="representativeId")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    name: Optional[str]
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    sex_name_url_slug: Optional[str] = Field(alias="sexNameUrlSlug")
    friendly_name: Optional[str] = Field(alias="friendlyName")
    friendly_name_letter: Optional[str] = Field(alias="friendlyNameLetter")
    friendly_name_first3_letter: Optional[str] = Field(alias="friendlyNameFirst3Letter")


class GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitions(BaseModel):
    id: Optional[str]
    name: Optional[str]
    circuit_type_code: Optional[str] = Field(alias="circuitTypeCode")
    event_sub_category_code: Optional[str] = Field(alias="eventSubCategoryCode")
    description: Optional[str]
    circuit_code: Optional[str] = Field(alias="circuitCode")
    url_slug: Optional[str] = Field(alias="urlSlug")
    order: Optional[int]
    category: Optional[int]
    about: Optional[str]
    primary_media_id: Optional[str] = Field(alias="primaryMediaId")
    related_media_ids: Optional[List[Optional[str]]] = Field(alias="relatedMediaIds")
    logo_light_id: Optional[str] = Field(alias="logoLightId")
    logo_dark_id: Optional[str] = Field(alias="logoDarkId")
    style_overrides: Optional[str] = Field(alias="styleOverrides")
    related_info: Optional[List[Optional[str]]] = Field(alias="relatedInfo")
    next_event_start_date: Optional[Any] = Field(alias="nextEventStartDate")
    page_id: Optional[str] = Field(alias="pageId")


class GetArticleGetArticleRelatedArticlesRelatedDiscipline(BaseModel):
    id: Optional[str]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    name: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    type_name: Optional[str] = Field(alias="typeName")
    type_order: Optional[int] = Field(alias="typeOrder")
    order: Optional[int]
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_road: Optional[bool] = Field(alias="isRoad")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")


class GetArticleGetArticleRelatedArticlesRelatedCompetitors(BaseModel):
    id: Optional[int]
    media_ids: Optional[List[Optional[int]]] = Field(alias="mediaIds")
    related_media: Optional[
        List[
            Optional[
                "GetArticleGetArticleRelatedArticlesRelatedCompetitorsRelatedMedia"
            ]
        ]
    ] = Field(alias="relatedMedia")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    birth_date_str: Optional[str] = Field(alias="birthDateStr")
    url_slug: Optional[str] = Field(alias="urlSlug")
    representative_id: Optional[int] = Field(alias="representativeId")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    name: Optional[str]
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    sex_name_url_slug: Optional[str] = Field(alias="sexNameUrlSlug")
    friendly_name: Optional[str] = Field(alias="friendlyName")
    friendly_name_letter: Optional[str] = Field(alias="friendlyNameLetter")
    friendly_name_first3_letter: Optional[str] = Field(alias="friendlyNameFirst3Letter")


class GetArticleGetArticleRelatedArticlesRelatedCompetitorsRelatedMedia(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


class GetArticleGetArticleRelatedArticlesRelatedCompetitions(BaseModel):
    id: Optional[str]
    name: Optional[str]
    circuit_type_code: Optional[str] = Field(alias="circuitTypeCode")
    event_sub_category_code: Optional[str] = Field(alias="eventSubCategoryCode")
    description: Optional[str]
    circuit_code: Optional[str] = Field(alias="circuitCode")
    url_slug: Optional[str] = Field(alias="urlSlug")
    order: Optional[int]
    category: Optional[int]
    about: Optional[str]
    primary_media_id: Optional[str] = Field(alias="primaryMediaId")
    related_media_ids: Optional[List[Optional[str]]] = Field(alias="relatedMediaIds")
    logo_light_id: Optional[str] = Field(alias="logoLightId")
    logo_dark_id: Optional[str] = Field(alias="logoDarkId")
    style_overrides: Optional[str] = Field(alias="styleOverrides")
    related_info: Optional[List[Optional[str]]] = Field(alias="relatedInfo")
    next_event: Optional[
        "GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEvent"
    ] = Field(alias="nextEvent")
    last_event: Optional[
        "GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEvent"
    ] = Field(alias="lastEvent")
    next_event_start_date: Optional[Any] = Field(alias="nextEventStartDate")
    page_id: Optional[str] = Field(alias="pageId")
    page: Optional["GetArticleGetArticleRelatedArticlesRelatedCompetitionsPage"]


class GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEvent(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    hash: Optional[str]
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    age_code: Optional[str] = Field(alias="ageCode")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")
    category_code: Optional[str] = Field(alias="categoryCode")
    category_name: Optional[str] = Field(alias="categoryName")
    category_order: Optional[int] = Field(alias="categoryOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    sub_category_name: Optional[str] = Field(alias="subCategoryName")
    show_web_live_banner: Optional[bool] = Field(alias="showWebLiveBanner")
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder")
    class_code: Optional[str] = Field(alias="classCode")
    class_order: Optional[int] = Field(alias="classOrder")
    is_published: Optional[bool] = Field(alias="isPublished")
    has_comp_doc_results: Optional[bool] = Field(alias="hasCompDocResults")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    start_date_year: Optional[int] = Field(alias="startDateYear")
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    category_name_url_slug: Optional[str] = Field(alias="categoryNameUrlSlug")
    sub_category_name_url_slug: Optional[str] = Field(alias="subCategoryNameUrlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    has_timetable: Optional[bool] = Field(alias="hasTimetable")
    event_start_date_time: Optional[Any] = Field(alias="eventStartDateTime")
    event_end_date_time: Optional[Any] = Field(alias="eventEndDateTime")
    venue_timezone: Optional[str] = Field(alias="venueTimezone")


class GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEvent(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    hash: Optional[str]
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    age_code: Optional[str] = Field(alias="ageCode")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")
    category_code: Optional[str] = Field(alias="categoryCode")
    category_name: Optional[str] = Field(alias="categoryName")
    category_order: Optional[int] = Field(alias="categoryOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    sub_category_name: Optional[str] = Field(alias="subCategoryName")
    show_web_live_banner: Optional[bool] = Field(alias="showWebLiveBanner")
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder")
    class_code: Optional[str] = Field(alias="classCode")
    class_order: Optional[int] = Field(alias="classOrder")
    is_published: Optional[bool] = Field(alias="isPublished")
    has_comp_doc_results: Optional[bool] = Field(alias="hasCompDocResults")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    start_date_year: Optional[int] = Field(alias="startDateYear")
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    category_name_url_slug: Optional[str] = Field(alias="categoryNameUrlSlug")
    sub_category_name_url_slug: Optional[str] = Field(alias="subCategoryNameUrlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    has_timetable: Optional[bool] = Field(alias="hasTimetable")
    event_start_date_time: Optional[Any] = Field(alias="eventStartDateTime")
    event_end_date_time: Optional[Any] = Field(alias="eventEndDateTime")
    venue_timezone: Optional[str] = Field(alias="venueTimezone")


class GetArticleGetArticleRelatedArticlesRelatedCompetitionsPage(BaseModel):
    id: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    language: Optional[str]
    title: Optional[str]
    competition_id: Optional[str] = Field(alias="competitionId")
    event_id: Optional[int] = Field(alias="eventId")
    site_id: Optional[str] = Field(alias="siteId")
    seo_description: Optional[str] = Field(alias="seoDescription")
    slug: Optional[str]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[Any]
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")


class GetArticleGetArticleRelatedDiscipline(BaseModel):
    id: Optional[str]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    name: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    type_name: Optional[str] = Field(alias="typeName")
    type_order: Optional[int] = Field(alias="typeOrder")
    order: Optional[int]
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_road: Optional[bool] = Field(alias="isRoad")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")


class GetArticleGetArticleRelatedCompetitors(BaseModel):
    id: Optional[int]
    media_ids: Optional[List[Optional[int]]] = Field(alias="mediaIds")
    related_media: Optional[
        List[Optional["GetArticleGetArticleRelatedCompetitorsRelatedMedia"]]
    ] = Field(alias="relatedMedia")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    birth_date_str: Optional[str] = Field(alias="birthDateStr")
    url_slug: Optional[str] = Field(alias="urlSlug")
    representative_id: Optional[int] = Field(alias="representativeId")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    name: Optional[str]
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    sex_name_url_slug: Optional[str] = Field(alias="sexNameUrlSlug")
    friendly_name: Optional[str] = Field(alias="friendlyName")
    friendly_name_letter: Optional[str] = Field(alias="friendlyNameLetter")
    friendly_name_first3_letter: Optional[str] = Field(alias="friendlyNameFirst3Letter")


class GetArticleGetArticleRelatedCompetitorsRelatedMedia(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


class GetArticleGetArticleRelatedCompetitions(BaseModel):
    id: Optional[str]
    name: Optional[str]
    circuit_type_code: Optional[str] = Field(alias="circuitTypeCode")
    event_sub_category_code: Optional[str] = Field(alias="eventSubCategoryCode")
    description: Optional[str]
    circuit_code: Optional[str] = Field(alias="circuitCode")
    url_slug: Optional[str] = Field(alias="urlSlug")
    order: Optional[int]
    category: Optional[int]
    about: Optional[str]
    primary_media_id: Optional[str] = Field(alias="primaryMediaId")
    related_media_ids: Optional[List[Optional[str]]] = Field(alias="relatedMediaIds")
    logo_light_id: Optional[str] = Field(alias="logoLightId")
    logo_dark_id: Optional[str] = Field(alias="logoDarkId")
    style_overrides: Optional[str] = Field(alias="styleOverrides")
    related_info: Optional[List[Optional[str]]] = Field(alias="relatedInfo")
    next_event: Optional["GetArticleGetArticleRelatedCompetitionsNextEvent"] = Field(
        alias="nextEvent"
    )
    last_event: Optional["GetArticleGetArticleRelatedCompetitionsLastEvent"] = Field(
        alias="lastEvent"
    )
    next_event_start_date: Optional[Any] = Field(alias="nextEventStartDate")
    page_id: Optional[str] = Field(alias="pageId")
    page: Optional["GetArticleGetArticleRelatedCompetitionsPage"]


class GetArticleGetArticleRelatedCompetitionsNextEvent(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    hash: Optional[str]
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    age_code: Optional[str] = Field(alias="ageCode")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")
    category_code: Optional[str] = Field(alias="categoryCode")
    category_name: Optional[str] = Field(alias="categoryName")
    category_order: Optional[int] = Field(alias="categoryOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    sub_category_name: Optional[str] = Field(alias="subCategoryName")
    show_web_live_banner: Optional[bool] = Field(alias="showWebLiveBanner")
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder")
    class_code: Optional[str] = Field(alias="classCode")
    class_order: Optional[int] = Field(alias="classOrder")
    is_published: Optional[bool] = Field(alias="isPublished")
    has_comp_doc_results: Optional[bool] = Field(alias="hasCompDocResults")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    start_date_year: Optional[int] = Field(alias="startDateYear")
    circuits: Optional[
        List[Optional["GetArticleGetArticleRelatedCompetitionsNextEventCircuits"]]
    ]
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    category_name_url_slug: Optional[str] = Field(alias="categoryNameUrlSlug")
    sub_category_name_url_slug: Optional[str] = Field(alias="subCategoryNameUrlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    has_timetable: Optional[bool] = Field(alias="hasTimetable")
    page: Optional["GetArticleGetArticleRelatedCompetitionsNextEventPage"]
    event_start_date_time: Optional[Any] = Field(alias="eventStartDateTime")
    event_end_date_time: Optional[Any] = Field(alias="eventEndDateTime")
    venue_timezone: Optional[str] = Field(alias="venueTimezone")


class GetArticleGetArticleRelatedCompetitionsNextEventCircuits(BaseModel):
    updated_on: Optional[Any] = Field(alias="UpdatedOn")
    hash: Optional[str]
    circuit_code: Optional[str] = Field(alias="circuitCode")
    circuit_type_code: Optional[str] = Field(alias="circuitTypeCode")
    circuit_name: Optional[str] = Field(alias="circuitName")
    season: Optional[int]
    circuit_order: Optional[int] = Field(alias="circuitOrder")
    circuit_type_name: Optional[str] = Field(alias="circuitTypeName")


class GetArticleGetArticleRelatedCompetitionsNextEventPage(BaseModel):
    id: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    language: Optional[str]
    title: Optional[str]
    competition_id: Optional[str] = Field(alias="competitionId")
    event_id: Optional[int] = Field(alias="eventId")
    site_id: Optional[str] = Field(alias="siteId")
    seo_description: Optional[str] = Field(alias="seoDescription")
    slug: Optional[str]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[Any]
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")


class GetArticleGetArticleRelatedCompetitionsLastEvent(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    hash: Optional[str]
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    age_code: Optional[str] = Field(alias="ageCode")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")
    category_code: Optional[str] = Field(alias="categoryCode")
    category_name: Optional[str] = Field(alias="categoryName")
    category_order: Optional[int] = Field(alias="categoryOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    sub_category_name: Optional[str] = Field(alias="subCategoryName")
    show_web_live_banner: Optional[bool] = Field(alias="showWebLiveBanner")
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder")
    class_code: Optional[str] = Field(alias="classCode")
    class_order: Optional[int] = Field(alias="classOrder")
    is_published: Optional[bool] = Field(alias="isPublished")
    has_comp_doc_results: Optional[bool] = Field(alias="hasCompDocResults")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    start_date_year: Optional[int] = Field(alias="startDateYear")
    circuits: Optional[
        List[Optional["GetArticleGetArticleRelatedCompetitionsLastEventCircuits"]]
    ]
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    category_name_url_slug: Optional[str] = Field(alias="categoryNameUrlSlug")
    sub_category_name_url_slug: Optional[str] = Field(alias="subCategoryNameUrlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    has_timetable: Optional[bool] = Field(alias="hasTimetable")
    page: Optional["GetArticleGetArticleRelatedCompetitionsLastEventPage"]
    event_start_date_time: Optional[Any] = Field(alias="eventStartDateTime")
    event_end_date_time: Optional[Any] = Field(alias="eventEndDateTime")
    venue_timezone: Optional[str] = Field(alias="venueTimezone")


class GetArticleGetArticleRelatedCompetitionsLastEventCircuits(BaseModel):
    updated_on: Optional[Any] = Field(alias="UpdatedOn")
    hash: Optional[str]
    circuit_code: Optional[str] = Field(alias="circuitCode")
    circuit_type_code: Optional[str] = Field(alias="circuitTypeCode")
    circuit_name: Optional[str] = Field(alias="circuitName")
    season: Optional[int]
    circuit_order: Optional[int] = Field(alias="circuitOrder")
    circuit_type_name: Optional[str] = Field(alias="circuitTypeName")


class GetArticleGetArticleRelatedCompetitionsLastEventPage(BaseModel):
    id: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    language: Optional[str]
    title: Optional[str]
    competition_id: Optional[str] = Field(alias="competitionId")
    event_id: Optional[int] = Field(alias="eventId")
    site_id: Optional[str] = Field(alias="siteId")
    seo_description: Optional[str] = Field(alias="seoDescription")
    slug: Optional[str]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[Any]
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")


class GetArticleGetArticleRelatedCompetitionsPage(BaseModel):
    id: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    language: Optional[str]
    title: Optional[str]
    competition_id: Optional[str] = Field(alias="competitionId")
    event_id: Optional[int] = Field(alias="eventId")
    event: Optional["GetArticleGetArticleRelatedCompetitionsPageEvent"]
    site_id: Optional[str] = Field(alias="siteId")
    minisite: Optional["GetArticleGetArticleRelatedCompetitionsPageMinisite"]
    seo_description: Optional[str] = Field(alias="seoDescription")
    slug: Optional[str]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[Any]
    content_modules: Optional[
        List[Optional["GetArticleGetArticleRelatedCompetitionsPageContentModules"]]
    ] = Field(alias="contentModules")
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")
    campaign: Optional["GetArticleGetArticleRelatedCompetitionsPageCampaign"]


class GetArticleGetArticleRelatedCompetitionsPageEvent(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    hash: Optional[str]
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    age_code: Optional[str] = Field(alias="ageCode")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")
    category_code: Optional[str] = Field(alias="categoryCode")
    category_name: Optional[str] = Field(alias="categoryName")
    category_order: Optional[int] = Field(alias="categoryOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    sub_category_name: Optional[str] = Field(alias="subCategoryName")
    show_web_live_banner: Optional[bool] = Field(alias="showWebLiveBanner")
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder")
    class_code: Optional[str] = Field(alias="classCode")
    class_order: Optional[int] = Field(alias="classOrder")
    is_published: Optional[bool] = Field(alias="isPublished")
    has_comp_doc_results: Optional[bool] = Field(alias="hasCompDocResults")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    start_date_year: Optional[int] = Field(alias="startDateYear")
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    category_name_url_slug: Optional[str] = Field(alias="categoryNameUrlSlug")
    sub_category_name_url_slug: Optional[str] = Field(alias="subCategoryNameUrlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    has_timetable: Optional[bool] = Field(alias="hasTimetable")
    event_start_date_time: Optional[Any] = Field(alias="eventStartDateTime")
    event_end_date_time: Optional[Any] = Field(alias="eventEndDateTime")
    venue_timezone: Optional[str] = Field(alias="venueTimezone")


class GetArticleGetArticleRelatedCompetitionsPageMinisite(BaseModel):
    id: Optional[str]
    name: Optional[str]
    logo_id: Optional[str] = Field(alias="logoId")
    logo_edited: Optional[str] = Field(alias="logoEdited")
    feature_image_id: Optional[str] = Field(alias="featureImageId")
    feature_image_edited: Optional[str] = Field(alias="featureImageEdited")
    theme: Optional[str]
    default_sponsor_ids: Optional[List[Optional[str]]] = Field(
        alias="defaultSponsorIds"
    )
    sponsor_ids: Optional[List[Optional[str]]] = Field(alias="sponsorIds")
    event_id: Optional[int] = Field(alias="eventId")
    primary_color: Optional[str] = Field(alias="primaryColor")
    secondary_color: Optional[str] = Field(alias="secondaryColor")
    tertiary_color: Optional[str] = Field(alias="tertiaryColor")
    additional_colours: Optional[List[Optional[str]]] = Field(alias="additionalColours")
    language_codes: Optional[List[Optional[str]]] = Field(alias="languageCodes")


class GetArticleGetArticleRelatedCompetitionsPageContentModules(BaseModel):
    module_type: Optional[str] = Field(alias="moduleType")
    language: Optional[str]
    related_article_ids: List[Optional[str]] = Field(alias="relatedArticleIds")
    event_ids: List[Optional[int]] = Field(alias="eventIds")
    related_competitor_ids: List[Optional[int]] = Field(alias="relatedCompetitorIds")
    related_discipline_codes: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplineCodes"
    )
    athlete_ids: Optional[List[Optional[str]]] = Field(alias="athleteIds")
    media_ids: List[Optional[str]] = Field(alias="mediaIds")
    social_links: Optional[List[Optional[str]]] = Field(alias="socialLinks")
    minisite_id: Optional[str] = Field(alias="minisiteId")
    location_id: Optional[str] = Field(alias="locationId")
    event_id: Optional[int] = Field(alias="eventId")
    tags: Optional[List[Optional[str]]]
    description: Optional[str]
    event_name: Optional[str] = Field(alias="eventName")
    tag_id: Optional[str] = Field(alias="tagId")
    more_news_link: Optional[str] = Field(alias="moreNewsLink")
    more_news_text: Optional[str] = Field(alias="moreNewsText")
    colour: Optional[str]
    image_edited: Optional[str] = Field(alias="imageEdited")
    text_position: Optional[str] = Field(alias="textPosition")
    text_colour: Optional[str] = Field(alias="textColour")
    title: Optional[str]
    top_title: Optional[str] = Field(alias="topTitle")
    bottom_title: Optional[str] = Field(alias="bottomTitle")
    subtitle: Optional[str]
    category: Optional[str]
    standfirst: Optional[str]
    url: Optional[str]
    button_text: Optional[str] = Field(alias="buttonText")
    image_position: Optional[str] = Field(alias="imagePosition")
    background_color: Optional[str] = Field(alias="backgroundColor")
    show_timestamp: Optional[bool] = Field(alias="showTimestamp")
    content: Optional[str]
    parent_id: Optional[str] = Field(alias="parentId")
    event_id_wa: Optional[int] = Field(alias="eventIdWa")
    layout: Optional[int]
    slug: Optional[str]
    video_ids: Optional[List[Optional[str]]] = Field(alias="videoIds")
    video_playlist_id: Optional[str] = Field(alias="videoPlaylistId")
    video_id: Optional[str] = Field(alias="videoId")


class GetArticleGetArticleRelatedCompetitionsPageCampaign(BaseModel):
    id: Optional[str]
    name: Optional[str]
    tag: Optional[str]
    type: Optional[str]
    description: Optional[str]
    thank_you_message: Optional[str] = Field(alias="thankYouMessage")
    already_signed_message: Optional[str] = Field(alias="alreadySignedMessage")
    close_date: Optional[Any] = Field(alias="closeDate")
    redirect_url: Optional[str] = Field(alias="redirectUrl")
    tag_user_friendly_name: Optional[str] = Field(alias="tagUserFriendlyName")
    background_image_edited: Optional[str] = Field(alias="backgroundImageEdited")
    header_image_edited: Optional[str] = Field(alias="headerImageEdited")
    visible_on_preference_center: Optional[bool] = Field(
        alias="visibleOnPreferenceCenter"
    )
    short_form: Optional[bool] = Field(alias="shortForm")
    top_level_bucket_id: Optional[str] = Field(alias="topLevelBucketId")


GetArticle.update_forward_refs()
GetArticleGetArticle.update_forward_refs()
GetArticleGetArticleLocation.update_forward_refs()
GetArticleGetArticleRelatedMedia.update_forward_refs()
GetArticleGetArticleRelatedArticles.update_forward_refs()
GetArticleGetArticleRelatedArticlesLocation.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedMedia.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedArticles.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedArticlesLocation.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedMedia.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedArticles.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedDiscipline.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitors.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedArticlesRelatedCompetitions.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedDiscipline.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedCompetitors.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedCompetitorsRelatedMedia.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedCompetitions.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedCompetitionsNextEvent.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedCompetitionsLastEvent.update_forward_refs()
GetArticleGetArticleRelatedArticlesRelatedCompetitionsPage.update_forward_refs()
GetArticleGetArticleRelatedDiscipline.update_forward_refs()
GetArticleGetArticleRelatedCompetitors.update_forward_refs()
GetArticleGetArticleRelatedCompetitorsRelatedMedia.update_forward_refs()
GetArticleGetArticleRelatedCompetitions.update_forward_refs()
GetArticleGetArticleRelatedCompetitionsNextEvent.update_forward_refs()
GetArticleGetArticleRelatedCompetitionsNextEventCircuits.update_forward_refs()
GetArticleGetArticleRelatedCompetitionsNextEventPage.update_forward_refs()
GetArticleGetArticleRelatedCompetitionsLastEvent.update_forward_refs()
GetArticleGetArticleRelatedCompetitionsLastEventCircuits.update_forward_refs()
GetArticleGetArticleRelatedCompetitionsLastEventPage.update_forward_refs()
GetArticleGetArticleRelatedCompetitionsPage.update_forward_refs()
GetArticleGetArticleRelatedCompetitionsPageEvent.update_forward_refs()
GetArticleGetArticleRelatedCompetitionsPageMinisite.update_forward_refs()
GetArticleGetArticleRelatedCompetitionsPageContentModules.update_forward_refs()
GetArticleGetArticleRelatedCompetitionsPageCampaign.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetMedals(BaseModel):
    get_medals: Optional[List[Optional["GetMedalsGetMedals"]]] = Field(
        alias="getMedals"
    )


class GetMedalsGetMedals(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    event_id: Optional[int] = Field(alias="eventId")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    country_code: Optional[str] = Field(alias="countryCode")
    medal_rank: Optional[str] = Field(alias="medalRank")
    silver: Optional[int]
    gold: Optional[int]
    bronze: Optional[int]
    total: Optional[int]
    event_medal_table_order: Optional[int] = Field(alias="eventMedalTableOrder")
    country: Optional["GetMedalsGetMedalsCountry"]
    event_sub_category_code: Optional[str] = Field(alias="eventSubCategoryCode")


class GetMedalsGetMedalsCountry(BaseModel):
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    id: Optional[str] = Field(alias="_id")
    country_name: Optional[str] = Field(alias="countryName")
    country_order: Optional[int] = Field(alias="countryOrder")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    area_order: Optional[int] = Field(alias="areaOrder")
    is_valid: Optional[bool] = Field(alias="isValid")
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    country_name_url_slug: Optional[str] = Field(alias="countryNameUrlSlug")


GetMedals.update_forward_refs()
GetMedalsGetMedals.update_forward_refs()
GetMedalsGetMedalsCountry.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetSpikes(BaseModel):
    get_spikes: Optional[List[Optional["GetSpikesGetSpikes"]]] = Field(
        alias="getSpikes"
    )


class GetSpikesGetSpikes(BaseModel):
    id: Optional[str]
    title: Optional[str]
    spikes_language: Optional[int] = Field(alias="spikesLanguage")
    seo_title: Optional[str] = Field(alias="seoTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    meta_description: Optional[str] = Field(alias="metaDescription")
    stand_first: Optional[str] = Field(alias="standFirst")
    body: Optional[str]
    plain_text_body: Optional[str] = Field(alias="plainTextBody")
    article_type: Optional[int] = Field(alias="articleType")
    primary_media_id: Optional[List[Optional[str]]] = Field(alias="primaryMediaId")
    primary_media: Optional[List[Optional["GetSpikesGetSpikesPrimaryMedia"]]] = Field(
        alias="primaryMedia"
    )
    related_discipline_codes: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplineCodes"
    )
    related_discipline_type_name_urls_slugs: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplineTypeNameUrlsSlugs"
    )
    related_competitor_ids: Optional[List[Optional[int]]] = Field(
        alias="relatedCompetitorIds"
    )
    related_competition_ids: Optional[List[Optional[int]]] = Field(
        alias="relatedCompetitionIds"
    )
    related_tags: Optional[List[Optional["GetSpikesGetSpikesRelatedTags"]]] = Field(
        alias="relatedTags"
    )
    champion_ship: Optional[bool] = Field(alias="championShip")
    featured: Optional[bool]
    featured_order: Optional[int] = Field(alias="featuredOrder")
    status: Optional[int]
    live_from: Optional[Any] = Field(alias="liveFrom")
    created_on: Optional[Any] = Field(alias="createdOn")
    updated_by_id: Optional[str] = Field(alias="updatedById")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    tags: Optional[List[Optional[str]]]
    tumblr_url: Optional[str] = Field(alias="tumblrUrl")
    spikes_article_type: Optional[int] = Field(alias="spikesArticleType")
    live_from_day: Optional[int] = Field(alias="liveFromDay")
    live_from_month: Optional[int] = Field(alias="liveFromMonth")
    live_from_year: Optional[int] = Field(alias="liveFromYear")


class GetSpikesGetSpikesPrimaryMedia(BaseModel):
    id: Optional[str]
    title: Optional[str]
    s_e_o_title: Optional[str] = Field(alias="sEOTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    credit: Optional[str]
    show_in_media: Optional[bool] = Field(alias="showInMedia")
    complete: Optional[bool]
    file_name: Optional[str] = Field(alias="fileName")
    remote_item_code: Optional[str] = Field(alias="remoteItemCode")
    x_m_l_file_name360: Optional[str] = Field(alias="xMLFileName360")
    file_name_url: Optional[str] = Field(alias="fileNameUrl")
    type: Optional[int]
    format: Optional[int]
    hosting: Optional[int]
    related_links: Optional[List[Optional[str]]] = Field(alias="relatedLinks")
    source_width: Optional[int] = Field(alias="sourceWidth")
    source_height: Optional[int] = Field(alias="sourceHeight")
    available_ratios: Optional[List[Optional[int]]] = Field(alias="availableRatios")
    related_sex_codes: Optional[List[Optional[int]]] = Field(alias="relatedSexCodes")
    related_age_groups: Optional[List[Optional[int]]] = Field(alias="relatedAgeGroups")
    related_event_phases: Optional[List[Optional[int]]] = Field(
        alias="relatedEventPhases"
    )
    status: Optional[int]
    live_from: Optional[Any] = Field(alias="liveFrom")
    created_on: Optional[str] = Field(alias="createdOn")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    created_by_id: Optional[str] = Field(alias="createdById")
    updated_by_id: Optional[str] = Field(alias="updatedById")


class GetSpikesGetSpikesRelatedTags(BaseModel):
    id: Optional[str]
    display_text: Optional[str] = Field(alias="displayText")
    url: Optional[str]


GetSpikes.update_forward_refs()
GetSpikesGetSpikes.update_forward_refs()
GetSpikesGetSpikesPrimaryMedia.update_forward_refs()
GetSpikesGetSpikesRelatedTags.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetPreChampionshipHighlights(BaseModel):
    get_pre_championship_highlights: Optional[
        "GetPreChampionshipHighlightsGetPreChampionshipHighlights"
    ] = Field(alias="getPreChampionshipHighlights")


class GetPreChampionshipHighlightsGetPreChampionshipHighlights(BaseModel):
    events: Optional[
        List[Optional["GetPreChampionshipHighlightsGetPreChampionshipHighlightsEvents"]]
    ]


class GetPreChampionshipHighlightsGetPreChampionshipHighlightsEvents(BaseModel):
    discipline: Optional[str]
    ranking_leaders: Optional[
        List[
            Optional[
                "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeaders"
            ]
        ]
    ] = Field(alias="rankingLeaders")
    reigning_champions: Optional[
        List[
            Optional[
                "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampions"
            ]
        ]
    ] = Field(alias="reigningChampions")
    sex: Optional[str]
    world_leaders: Optional[
        List[
            Optional[
                "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeaders"
            ]
        ]
    ] = Field(alias="worldLeaders")


class GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeaders(
    BaseModel
):
    birth_date: Optional[str] = Field(alias="birthDate")
    country: Optional[str]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    id: Optional[int]
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    team_members: Optional[
        List[
            Optional[
                "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeadersTeamMembers"
            ]
        ]
    ] = Field(alias="teamMembers")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")


class GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeadersTeamMembers(
    BaseModel
):
    birth_date: Optional[str] = Field(alias="birthDate")
    country: Optional[str]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    id: Optional[int]
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")


class GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampions(
    BaseModel
):
    birth_date: Optional[str] = Field(alias="birthDate")
    country: Optional[str]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    id: Optional[int]
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    team_members: Optional[
        List[
            Optional[
                "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampionsTeamMembers"
            ]
        ]
    ] = Field(alias="teamMembers")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")


class GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampionsTeamMembers(
    BaseModel
):
    birth_date: Optional[str] = Field(alias="birthDate")
    country: Optional[str]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    id: Optional[int]
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")


class GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeaders(
    BaseModel
):
    birth_date: Optional[str] = Field(alias="birthDate")
    country: Optional[str]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    id: Optional[int]
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    team_members: Optional[
        List[
            Optional[
                "GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeadersTeamMembers"
            ]
        ]
    ] = Field(alias="teamMembers")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")


class GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeadersTeamMembers(
    BaseModel
):
    birth_date: Optional[str] = Field(alias="birthDate")
    country: Optional[str]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    id: Optional[int]
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")


GetPreChampionshipHighlights.update_forward_refs()
GetPreChampionshipHighlightsGetPreChampionshipHighlights.update_forward_refs()
GetPreChampionshipHighlightsGetPreChampionshipHighlightsEvents.update_forward_refs()
GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeaders.update_forward_refs()
GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsRankingLeadersTeamMembers.update_forward_refs()
GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampions.update_forward_refs()
GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsReigningChampionsTeamMembers.update_forward_refs()
GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeaders.update_forward_refs()
GetPreChampionshipHighlightsGetPreChampionshipHighlightsEventsWorldLeadersTeamMembers.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetEventBrokenRecords(BaseModel):
    get_event_broken_records: Optional[
        List[Optional["GetEventBrokenRecordsGetEventBrokenRecords"]]
    ] = Field(alias="getEventBrokenRecords")


class GetEventBrokenRecordsGetEventBrokenRecords(BaseModel):
    id: Optional[int]
    phase_id: Optional[int] = Field(alias="phaseId")
    event_id: Optional[int] = Field(alias="eventId")
    record_order: Optional[int] = Field(alias="recordOrder")
    record_type_order: Optional[int] = Field(alias="recordTypeOrder")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    record: Optional[str]
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    surname: Optional[str]
    forename: Optional[str]
    unit_name: Optional[str] = Field(alias="unitName")
    area_code: Optional[str] = Field(alias="areaCode")
    phase_name: Optional[str] = Field(alias="phaseName")
    phase_code: Optional[str] = Field(alias="phaseCode")
    sex_url_slug: Optional[str] = Field(alias="sexUrlSlug")
    result_rank: Optional[str] = Field(alias="resultRank")
    result_mark: Optional[str] = Field(alias="resultMark")
    record_name: Optional[str] = Field(alias="recordName")
    event_id__w_a: Optional[str] = Field(alias="eventId_WA")
    birth_date_str: Optional[str] = Field(alias="birthDateStr")
    unit_type_name: Optional[str] = Field(alias="unitTypeName")
    phase_url_slug: Optional[str] = Field(alias="phaseUrlSlug")
    competitor_id: Optional[str] = Field(alias="competitorId")
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline: Optional["GetEventBrokenRecordsGetEventBrokenRecordsDiscipline"]
    competitor_type_code: Optional[str] = Field(alias="competitorTypeCode")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    equalled: Optional[bool]
    updated_on: Optional[Any] = Field(alias="updatedOn")


class GetEventBrokenRecordsGetEventBrokenRecordsDiscipline(BaseModel):
    discipline_name: Optional[str] = Field(alias="disciplineName")
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    type_name: Optional[str] = Field(alias="typeName")
    men: Optional[bool]
    women: Optional[bool]
    is_road: Optional[bool] = Field(alias="isRoad")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    order: Optional[int]
    type_order: Optional[int] = Field(alias="typeOrder")
    id: Optional[str]
    name: Optional[str]
    hash: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")
    updated_on: Optional[Any] = Field(alias="updatedOn")


GetEventBrokenRecords.update_forward_refs()
GetEventBrokenRecordsGetEventBrokenRecords.update_forward_refs()
GetEventBrokenRecordsGetEventBrokenRecordsDiscipline.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class CompetitionsByCountry(BaseModel):
    competitions_by_country: Optional[
        "CompetitionsByCountryCompetitionsByCountry"
    ] = Field(alias="competitionsByCountry")


class CompetitionsByCountryCompetitionsByCountry(BaseModel):
    results: Optional[
        List[Optional["CompetitionsByCountryCompetitionsByCountryResults"]]
    ]
    parameters: Optional["CompetitionsByCountryCompetitionsByCountryParameters"]


class CompetitionsByCountryCompetitionsByCountryResults(BaseModel):
    area: Optional[str]
    competition_group: Optional[str] = Field(alias="competitionGroup")
    date_range: Optional[str] = Field(alias="dateRange")
    disciplines: Optional[str]
    end_date: Optional[str] = Field(alias="endDate")
    has_results: Optional[bool] = Field(alias="hasResults")
    has_startlist: Optional[bool] = Field(alias="hasStartlist")
    id: Optional[int]
    match_type: Optional[str] = Field(alias="matchType")
    name: Optional[str]
    ranking_category: Optional[str] = Field(alias="rankingCategory")
    start_date: Optional[str] = Field(alias="startDate")
    undetermined_competition_period: Optional[str] = Field(
        alias="undeterminedCompetitionPeriod"
    )
    venue: Optional[str]


class CompetitionsByCountryCompetitionsByCountryParameters(BaseModel):
    country_of_residence: Optional[str] = Field(alias="countryOfResidence")
    limit: Optional[int]
    preferred_country: Optional[str] = Field(alias="preferredCountry")


CompetitionsByCountry.update_forward_refs()
CompetitionsByCountryCompetitionsByCountry.update_forward_refs()
CompetitionsByCountryCompetitionsByCountryResults.update_forward_refs()
CompetitionsByCountryCompetitionsByCountryParameters.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetAthleteProfileAthleteRepresentative(BaseModel):
    get_athlete_profile_athlete_representative: Optional[
        "GetAthleteProfileAthleteRepresentativeGetAthleteProfileAthleteRepresentative"
    ] = Field(alias="getAthleteProfileAthleteRepresentative")


class GetAthleteProfileAthleteRepresentativeGetAthleteProfileAthleteRepresentative(
    BaseModel
):
    athlete_representative_id: Optional[int] = Field(alias="athleteRepresentativeId")
    country_code: Optional[str] = Field(alias="countryCode")
    telephone: Optional[List[Optional[str]]]
    first_name: Optional[str] = Field(alias="firstName")
    website: Optional[List[Optional[str]]]
    last_name: Optional[str] = Field(alias="lastName")
    mobile: Optional[List[Optional[str]]]
    country: Optional[str]
    email: Optional[List[Optional[str]]]


GetAthleteProfileAthleteRepresentative.update_forward_refs()
GetAthleteProfileAthleteRepresentativeGetAthleteProfileAthleteRepresentative.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetWawEvent(BaseModel):
    get_waw_event: Optional["GetWawEventGetWawEvent"] = Field(alias="getWawEvent")


class GetWawEventGetWawEvent(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    hash: Optional[str]
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    age_code: Optional[str] = Field(alias="ageCode")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")
    category_code: Optional[str] = Field(alias="categoryCode")
    category_name: Optional[str] = Field(alias="categoryName")
    category_order: Optional[int] = Field(alias="categoryOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    sub_category_name: Optional[str] = Field(alias="subCategoryName")
    show_web_live_banner: Optional[bool] = Field(alias="showWebLiveBanner")
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder")
    class_code: Optional[str] = Field(alias="classCode")
    class_order: Optional[int] = Field(alias="classOrder")
    is_published: Optional[bool] = Field(alias="isPublished")
    has_comp_doc_results: Optional[bool] = Field(alias="hasCompDocResults")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    start_date_year: Optional[int] = Field(alias="startDateYear")
    circuits: Optional[List[Optional["GetWawEventGetWawEventCircuits"]]]
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    category_name_url_slug: Optional[str] = Field(alias="categoryNameUrlSlug")
    sub_category_name_url_slug: Optional[str] = Field(alias="subCategoryNameUrlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    has_timetable: Optional[bool] = Field(alias="hasTimetable")
    page: Optional["GetWawEventGetWawEventPage"]
    event_start_date_time: Optional[Any] = Field(alias="eventStartDateTime")
    event_end_date_time: Optional[Any] = Field(alias="eventEndDateTime")
    venue_timezone: Optional[str] = Field(alias="venueTimezone")


class GetWawEventGetWawEventCircuits(BaseModel):
    updated_on: Optional[Any] = Field(alias="UpdatedOn")
    hash: Optional[str]
    circuit_code: Optional[str] = Field(alias="circuitCode")
    circuit_type_code: Optional[str] = Field(alias="circuitTypeCode")
    circuit_name: Optional[str] = Field(alias="circuitName")
    season: Optional[int]
    circuit_order: Optional[int] = Field(alias="circuitOrder")
    circuit_type_name: Optional[str] = Field(alias="circuitTypeName")


class GetWawEventGetWawEventPage(BaseModel):
    id: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    language: Optional[str]
    title: Optional[str]
    competition_id: Optional[str] = Field(alias="competitionId")
    event_id: Optional[int] = Field(alias="eventId")
    event: Optional["GetWawEventGetWawEventPageEvent"]
    site_id: Optional[str] = Field(alias="siteId")
    minisite: Optional["GetWawEventGetWawEventPageMinisite"]
    seo_description: Optional[str] = Field(alias="seoDescription")
    slug: Optional[str]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[Any]
    content_modules: Optional[
        List[Optional["GetWawEventGetWawEventPageContentModules"]]
    ] = Field(alias="contentModules")
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")
    campaign: Optional["GetWawEventGetWawEventPageCampaign"]


class GetWawEventGetWawEventPageEvent(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    hash: Optional[str]
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    age_code: Optional[str] = Field(alias="ageCode")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")
    category_code: Optional[str] = Field(alias="categoryCode")
    category_name: Optional[str] = Field(alias="categoryName")
    category_order: Optional[int] = Field(alias="categoryOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    sub_category_name: Optional[str] = Field(alias="subCategoryName")
    show_web_live_banner: Optional[bool] = Field(alias="showWebLiveBanner")
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder")
    class_code: Optional[str] = Field(alias="classCode")
    class_order: Optional[int] = Field(alias="classOrder")
    is_published: Optional[bool] = Field(alias="isPublished")
    has_comp_doc_results: Optional[bool] = Field(alias="hasCompDocResults")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    start_date_year: Optional[int] = Field(alias="startDateYear")
    circuits: Optional[List[Optional["GetWawEventGetWawEventPageEventCircuits"]]]
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    category_name_url_slug: Optional[str] = Field(alias="categoryNameUrlSlug")
    sub_category_name_url_slug: Optional[str] = Field(alias="subCategoryNameUrlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    has_timetable: Optional[bool] = Field(alias="hasTimetable")
    page: Optional["GetWawEventGetWawEventPageEventPage"]
    event_start_date_time: Optional[Any] = Field(alias="eventStartDateTime")
    event_end_date_time: Optional[Any] = Field(alias="eventEndDateTime")
    venue_timezone: Optional[str] = Field(alias="venueTimezone")


class GetWawEventGetWawEventPageEventCircuits(BaseModel):
    updated_on: Optional[Any] = Field(alias="UpdatedOn")
    hash: Optional[str]
    circuit_code: Optional[str] = Field(alias="circuitCode")
    circuit_type_code: Optional[str] = Field(alias="circuitTypeCode")
    circuit_name: Optional[str] = Field(alias="circuitName")
    season: Optional[int]
    circuit_order: Optional[int] = Field(alias="circuitOrder")
    circuit_type_name: Optional[str] = Field(alias="circuitTypeName")


class GetWawEventGetWawEventPageEventPage(BaseModel):
    id: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    language: Optional[str]
    title: Optional[str]
    competition_id: Optional[str] = Field(alias="competitionId")
    event_id: Optional[int] = Field(alias="eventId")
    site_id: Optional[str] = Field(alias="siteId")
    seo_description: Optional[str] = Field(alias="seoDescription")
    slug: Optional[str]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[Any]
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")


class GetWawEventGetWawEventPageMinisite(BaseModel):
    id: Optional[str]
    name: Optional[str]
    logo_id: Optional[str] = Field(alias="logoId")
    logo: Optional["GetWawEventGetWawEventPageMinisiteLogo"]
    logo_edited: Optional[str] = Field(alias="logoEdited")
    feature_image_id: Optional[str] = Field(alias="featureImageId")
    feature_image: Optional["GetWawEventGetWawEventPageMinisiteFeatureImage"] = Field(
        alias="featureImage"
    )
    feature_image_edited: Optional[str] = Field(alias="featureImageEdited")
    theme: Optional[str]
    default_sponsor_ids: Optional[List[Optional[str]]] = Field(
        alias="defaultSponsorIds"
    )
    default_sponsors: Optional[
        List[Optional["GetWawEventGetWawEventPageMinisiteDefaultSponsors"]]
    ] = Field(alias="defaultSponsors")
    sponsor_ids: Optional[List[Optional[str]]] = Field(alias="sponsorIds")
    sponsors: Optional[List[Optional["GetWawEventGetWawEventPageMinisiteSponsors"]]]
    event_id: Optional[int] = Field(alias="eventId")
    primary_color: Optional[str] = Field(alias="primaryColor")
    secondary_color: Optional[str] = Field(alias="secondaryColor")
    tertiary_color: Optional[str] = Field(alias="tertiaryColor")
    additional_colours: Optional[List[Optional[str]]] = Field(alias="additionalColours")
    language_codes: Optional[List[Optional[str]]] = Field(alias="languageCodes")


class GetWawEventGetWawEventPageMinisiteLogo(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


class GetWawEventGetWawEventPageMinisiteFeatureImage(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


class GetWawEventGetWawEventPageMinisiteDefaultSponsors(BaseModel):
    id: Optional[str]
    event_id: Optional[int] = Field(alias="eventId")
    type: Optional[str]
    name: Optional[str]
    url: Optional[str]
    logo_scale: Optional[str] = Field(alias="logoScale")
    light_bg_logo_id: Optional[str] = Field(alias="lightBgLogoId")
    light_bg_logo_edited: Optional[str] = Field(alias="lightBgLogoEdited")
    dark_bg_logo_id: Optional[str] = Field(alias="darkBgLogoId")
    dark_bg_logo_edited: Optional[str] = Field(alias="darkBgLogoEdited")


class GetWawEventGetWawEventPageMinisiteSponsors(BaseModel):
    id: Optional[str]
    event_id: Optional[int] = Field(alias="eventId")
    type: Optional[str]
    name: Optional[str]
    url: Optional[str]
    logo_scale: Optional[str] = Field(alias="logoScale")
    light_bg_logo_id: Optional[str] = Field(alias="lightBgLogoId")
    light_bg_logo_edited: Optional[str] = Field(alias="lightBgLogoEdited")
    dark_bg_logo_id: Optional[str] = Field(alias="darkBgLogoId")
    dark_bg_logo_edited: Optional[str] = Field(alias="darkBgLogoEdited")


class GetWawEventGetWawEventPageContentModules(BaseModel):
    module_type: Optional[str] = Field(alias="moduleType")
    language: Optional[str]
    related_article_ids: List[Optional[str]] = Field(alias="relatedArticleIds")
    related_articles: Optional[
        List[Optional["GetWawEventGetWawEventPageContentModulesRelatedArticles"]]
    ] = Field(alias="relatedArticles")
    event_ids: List[Optional[int]] = Field(alias="eventIds")
    related_events: Optional[
        List[Optional["GetWawEventGetWawEventPageContentModulesRelatedEvents"]]
    ] = Field(alias="relatedEvents")
    related_competitor_ids: List[Optional[int]] = Field(alias="relatedCompetitorIds")
    related_competitors: Optional[
        List[Optional["GetWawEventGetWawEventPageContentModulesRelatedCompetitors"]]
    ] = Field(alias="relatedCompetitors")
    related_discipline_codes: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplineCodes"
    )
    related_discipline: Optional[
        List[Optional["GetWawEventGetWawEventPageContentModulesRelatedDiscipline"]]
    ] = Field(alias="relatedDiscipline")
    athlete_ids: Optional[List[Optional[str]]] = Field(alias="athleteIds")
    media_ids: List[Optional[str]] = Field(alias="mediaIds")
    related_media: Optional[
        List[Optional["GetWawEventGetWawEventPageContentModulesRelatedMedia"]]
    ] = Field(alias="relatedMedia")
    social_links: Optional[List[Optional[str]]] = Field(alias="socialLinks")
    lifestyle_links: Optional[
        List[Optional["GetWawEventGetWawEventPageContentModulesLifestyleLinks"]]
    ] = Field(alias="lifestyleLinks")
    feature_links: Optional[
        List[Optional["GetWawEventGetWawEventPageContentModulesFeatureLinks"]]
    ] = Field(alias="featureLinks")
    minisite_id: Optional[str] = Field(alias="minisiteId")
    minisite_page: Optional[
        "GetWawEventGetWawEventPageContentModulesMinisitePage"
    ] = Field(alias="minisitePage")
    minisite: Optional["GetWawEventGetWawEventPageContentModulesMinisite"]
    location_id: Optional[str] = Field(alias="locationId")
    locations: Optional[
        List[Optional["GetWawEventGetWawEventPageContentModulesLocations"]]
    ]
    event_id: Optional[int] = Field(alias="eventId")
    tags: Optional[List[Optional[str]]]
    videos: Optional[List[Optional["GetWawEventGetWawEventPageContentModulesVideos"]]]
    banners: Optional[List[Optional["GetWawEventGetWawEventPageContentModulesBanners"]]]
    slides: Optional[List[Optional["GetWawEventGetWawEventPageContentModulesSlides"]]]
    sections: Optional[
        List[Optional["GetWawEventGetWawEventPageContentModulesSections"]]
    ]
    description: Optional[str]
    event_name: Optional[str] = Field(alias="eventName")
    tag_id: Optional[str] = Field(alias="tagId")
    more_news_link: Optional[str] = Field(alias="moreNewsLink")
    more_news_text: Optional[str] = Field(alias="moreNewsText")
    colour: Optional[str]
    image_edited: Optional[str] = Field(alias="imageEdited")
    text_position: Optional[str] = Field(alias="textPosition")
    text_colour: Optional[str] = Field(alias="textColour")
    title: Optional[str]
    top_title: Optional[str] = Field(alias="topTitle")
    bottom_title: Optional[str] = Field(alias="bottomTitle")
    subtitle: Optional[str]
    category: Optional[str]
    standfirst: Optional[str]
    url: Optional[str]
    button_text: Optional[str] = Field(alias="buttonText")
    image_position: Optional[str] = Field(alias="imagePosition")
    background_color: Optional[str] = Field(alias="backgroundColor")
    show_timestamp: Optional[bool] = Field(alias="showTimestamp")
    content: Optional[str]
    parent_id: Optional[str] = Field(alias="parentId")
    event_id_wa: Optional[int] = Field(alias="eventIdWa")
    layout: Optional[int]
    slug: Optional[str]
    video_ids: Optional[List[Optional[str]]] = Field(alias="videoIds")
    video_playlist_id: Optional[str] = Field(alias="videoPlaylistId")
    related_videos: Optional[
        List[Optional["GetWawEventGetWawEventPageContentModulesRelatedVideos"]]
    ] = Field(alias="relatedVideos")
    video_id: Optional[str] = Field(alias="videoId")
    related_video: Optional[
        "GetWawEventGetWawEventPageContentModulesRelatedVideo"
    ] = Field(alias="relatedVideo")


class GetWawEventGetWawEventPageContentModulesRelatedArticles(BaseModel):
    id: Optional[str]
    title: Optional[str]
    body: Optional[str]
    content_id: Optional[str] = Field(alias="contentId")
    stand_first: Optional[str] = Field(alias="standFirst")
    standfirst: Optional[str]
    background_colour: Optional[str] = Field(alias="backgroundColour")
    seo_description: Optional[str] = Field(alias="seoDescription")
    s_e_o_title: Optional[str] = Field(alias="sEOTitle")
    seo_title: Optional[str] = Field(alias="seoTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    slug: Optional[str]
    campaign_id: Optional[str] = Field(alias="campaignId")
    related_urls: Optional[str] = Field(alias="relatedUrls")
    live_from: Optional[Any] = Field(alias="liveFrom")
    article_type: Optional[int] = Field(alias="articleType")
    feature_image_id: Optional[str] = Field(alias="featureImageId")
    feature_image_edited: Optional[str] = Field(alias="featureImageEdited")
    hide_on_the_main_site: Optional[bool] = Field(alias="hideOnTheMainSite")
    image_edited: Optional[str] = Field(alias="imageEdited")
    media_ids: Optional[List[Optional[str]]] = Field(alias="mediaIds")
    event_id: Optional[int] = Field(alias="eventId")
    blog_updated: Optional[str] = Field(alias="blogUpdated")
    live_blog: Optional[bool] = Field(alias="liveBlog")
    language: Optional[str]
    related_competitor_ids: List[Optional[int]] = Field(alias="relatedCompetitorIds")
    related_discipline_codes: List[Optional[str]] = Field(
        alias="relatedDisciplineCodes"
    )
    related_competition_ids: List[Optional[str]] = Field(alias="relatedCompetitionIds")
    related_event_ids: List[Optional[int]] = Field(alias="relatedEventIds")
    related_article_ids: List[Optional[str]] = Field(alias="relatedArticleIds")
    related_minisite_ids: Optional[List[Optional[str]]] = Field(
        alias="relatedMinisiteIds"
    )
    related_country_codes: Optional[List[Optional[str]]] = Field(
        alias="relatedCountryCodes"
    )
    related_region_codes: Optional[List[Optional[str]]] = Field(
        alias="relatedRegionCodes"
    )
    tags: Optional[List[Optional[str]]]
    published: Optional[Any]
    columns: Optional[int]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    related_articles_background_color: Optional[str] = Field(
        alias="relatedArticlesBackgroundColor"
    )
    gated_content: Optional[bool] = Field(alias="gatedContent")


class GetWawEventGetWawEventPageContentModulesRelatedEvents(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    hash: Optional[str]
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    age_code: Optional[str] = Field(alias="ageCode")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")
    category_code: Optional[str] = Field(alias="categoryCode")
    category_name: Optional[str] = Field(alias="categoryName")
    category_order: Optional[int] = Field(alias="categoryOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    sub_category_name: Optional[str] = Field(alias="subCategoryName")
    show_web_live_banner: Optional[bool] = Field(alias="showWebLiveBanner")
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder")
    class_code: Optional[str] = Field(alias="classCode")
    class_order: Optional[int] = Field(alias="classOrder")
    is_published: Optional[bool] = Field(alias="isPublished")
    has_comp_doc_results: Optional[bool] = Field(alias="hasCompDocResults")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    start_date_year: Optional[int] = Field(alias="startDateYear")
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    category_name_url_slug: Optional[str] = Field(alias="categoryNameUrlSlug")
    sub_category_name_url_slug: Optional[str] = Field(alias="subCategoryNameUrlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    has_timetable: Optional[bool] = Field(alias="hasTimetable")
    event_start_date_time: Optional[Any] = Field(alias="eventStartDateTime")
    event_end_date_time: Optional[Any] = Field(alias="eventEndDateTime")
    venue_timezone: Optional[str] = Field(alias="venueTimezone")


class GetWawEventGetWawEventPageContentModulesRelatedCompetitors(BaseModel):
    id: Optional[int]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    friendly_name: Optional[str] = Field(alias="friendlyName")
    full_name: Optional[str] = Field(alias="fullName")
    friendly_name_letter: Optional[str] = Field(alias="friendlyNameLetter")
    friendly_name_first3_letter: Optional[str] = Field(alias="friendlyNameFirst3Letter")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    birth_date: Optional[str] = Field(alias="birthDate")
    birth_place: Optional[str] = Field(alias="birthPlace")
    birth_place_country_name: Optional[str] = Field(alias="birthPlaceCountryName")
    sex_name_url_slug: Optional[str] = Field(alias="sexNameUrlSlug")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    birth_place_country_url_slug: Optional[str] = Field(
        alias="birthPlaceCountryUrlSlug"
    )
    birth_country_code: Optional[str] = Field(alias="birthCountryCode")
    primary_media_id: Optional[str] = Field(alias="primaryMediaId")
    primary_media_edited: Optional[str] = Field(alias="primaryMediaEdited")
    url_slug: Optional[str] = Field(alias="urlSlug")
    representative_id: Optional[int] = Field(alias="representativeId")
    biography: Optional[str]
    twitter_link: Optional[str] = Field(alias="twitterLink")
    instagram_link: Optional[str] = Field(alias="instagramLink")
    facebook_link: Optional[str] = Field(alias="facebookLink")
    transfers_of_allegiance: Optional[List[Optional[str]]] = Field(
        alias="transfersOfAllegiance"
    )
    aa_id: Optional[int] = Field(alias="aaId")
    country_full_name: Optional[str] = Field(alias="countryFullName")
    family_name: Optional[str] = Field(alias="familyName")
    given_name: Optional[str] = Field(alias="givenName")
    birth_date_str: Optional[str] = Field(alias="birthDateStr")
    facebook_username: Optional[str] = Field(alias="facebookUsername")
    twitter_username: Optional[str] = Field(alias="twitterUsername")
    instagram_username: Optional[str] = Field(alias="instagramUsername")
    media_ids: Optional[List[Optional[str]]] = Field(alias="mediaIds")


class GetWawEventGetWawEventPageContentModulesRelatedDiscipline(BaseModel):
    id: Optional[str]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    name: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    type_name: Optional[str] = Field(alias="typeName")
    type_order: Optional[int] = Field(alias="typeOrder")
    order: Optional[int]
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_road: Optional[bool] = Field(alias="isRoad")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")


class GetWawEventGetWawEventPageContentModulesRelatedMedia(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


class GetWawEventGetWawEventPageContentModulesLifestyleLinks(BaseModel):
    article_id: Optional[str] = Field(alias="articleId")
    title: Optional[str]
    subtitle: Optional[str]
    url: Optional[str]


class GetWawEventGetWawEventPageContentModulesFeatureLinks(BaseModel):
    name: Optional[str]
    url: Optional[str]


class GetWawEventGetWawEventPageContentModulesMinisitePage(BaseModel):
    id: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    language: Optional[str]
    title: Optional[str]
    competition_id: Optional[str] = Field(alias="competitionId")
    event_id: Optional[int] = Field(alias="eventId")
    site_id: Optional[str] = Field(alias="siteId")
    seo_description: Optional[str] = Field(alias="seoDescription")
    slug: Optional[str]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[Any]
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")


class GetWawEventGetWawEventPageContentModulesMinisite(BaseModel):
    id: Optional[str]
    name: Optional[str]
    logo_id: Optional[str] = Field(alias="logoId")
    logo_edited: Optional[str] = Field(alias="logoEdited")
    feature_image_id: Optional[str] = Field(alias="featureImageId")
    feature_image_edited: Optional[str] = Field(alias="featureImageEdited")
    theme: Optional[str]
    default_sponsor_ids: Optional[List[Optional[str]]] = Field(
        alias="defaultSponsorIds"
    )
    sponsor_ids: Optional[List[Optional[str]]] = Field(alias="sponsorIds")
    event_id: Optional[int] = Field(alias="eventId")
    primary_color: Optional[str] = Field(alias="primaryColor")
    secondary_color: Optional[str] = Field(alias="secondaryColor")
    tertiary_color: Optional[str] = Field(alias="tertiaryColor")
    additional_colours: Optional[List[Optional[str]]] = Field(alias="additionalColours")
    language_codes: Optional[List[Optional[str]]] = Field(alias="languageCodes")


class GetWawEventGetWawEventPageContentModulesLocations(BaseModel):
    location_id: Optional[str] = Field(alias="locationId")
    headline: Optional[str]
    description: Optional[str]
    link: Optional[str]
    image_id: Optional[str] = Field(alias="imageId")
    image_edited: Optional[str] = Field(alias="imageEdited")


class GetWawEventGetWawEventPageContentModulesVideos(BaseModel):
    thumbnail_image_id: Optional[str] = Field(alias="thumbnailImageId")
    thumbnail_image_edited: Optional[str] = Field(alias="thumbnailImageEdited")
    title: Optional[str]
    description: Optional[str]
    time: Optional[str]
    video: Optional[str]


class GetWawEventGetWawEventPageContentModulesBanners(BaseModel):
    image_id: Optional[str] = Field(alias="imageId")
    url: Optional[str]
    image_edited: Optional[str] = Field(alias="imageEdited")
    page_id: Optional[str] = Field(alias="pageId")


class GetWawEventGetWawEventPageContentModulesSlides(BaseModel):
    article_id: Optional[str] = Field(alias="articleId")
    article_title: Optional[str] = Field(alias="articleTitle")
    article_slug: Optional[str] = Field(alias="articleSlug")
    image_id: Optional[str] = Field(alias="imageId")
    image_edited: Optional[str] = Field(alias="imageEdited")
    text_position: Optional[str] = Field(alias="textPosition")
    colour: Optional[str]
    url: Optional[str]
    standfirst: Optional[str]
    link_url: Optional[str] = Field(alias="linkUrl")
    subtitle: Optional[str]
    title: Optional[str]
    video_url: Optional[str] = Field(alias="videoUrl")
    read_more_link: Optional[str] = Field(alias="readMoreLink")
    headline: Optional[str]
    strapline: Optional[str]
    read_more_text: Optional[str] = Field(alias="readMoreText")
    date: Optional[str]
    subheadline: Optional[str]


class GetWawEventGetWawEventPageContentModulesSections(BaseModel):
    title: Optional[str]
    show: Optional[bool]


class GetWawEventGetWawEventPageContentModulesRelatedVideos(BaseModel):
    id: Optional[str]
    content_id: Optional[str] = Field(alias="contentId")
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[str]
    language: Optional[str]
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")
    tags: Optional[List[Optional[str]]]
    title: Optional[str]
    thumbnail_id: Optional[str] = Field(alias="thumbnailId")
    thumbnail_edited: Optional[str] = Field(alias="thumbnailEdited")
    video_id: Optional[str] = Field(alias="videoId")
    player_id: Optional[str] = Field(alias="playerId")
    tag_id: Optional[str] = Field(alias="tagId")
    stand_first: Optional[str] = Field(alias="standFirst")


class GetWawEventGetWawEventPageContentModulesRelatedVideo(BaseModel):
    id: Optional[str]
    content_id: Optional[str] = Field(alias="contentId")
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[str]
    language: Optional[str]
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")
    tags: Optional[List[Optional[str]]]
    title: Optional[str]
    thumbnail_id: Optional[str] = Field(alias="thumbnailId")
    thumbnail_edited: Optional[str] = Field(alias="thumbnailEdited")
    video_id: Optional[str] = Field(alias="videoId")
    player_id: Optional[str] = Field(alias="playerId")
    tag_id: Optional[str] = Field(alias="tagId")
    stand_first: Optional[str] = Field(alias="standFirst")


class GetWawEventGetWawEventPageCampaign(BaseModel):
    id: Optional[str]
    name: Optional[str]
    tag: Optional[str]
    type: Optional[str]
    description: Optional[str]
    thank_you_message: Optional[str] = Field(alias="thankYouMessage")
    already_signed_message: Optional[str] = Field(alias="alreadySignedMessage")
    close_date: Optional[Any] = Field(alias="closeDate")
    redirect_url: Optional[str] = Field(alias="redirectUrl")
    tag_user_friendly_name: Optional[str] = Field(alias="tagUserFriendlyName")
    background_image_edited: Optional[str] = Field(alias="backgroundImageEdited")
    header_image_edited: Optional[str] = Field(alias="headerImageEdited")
    visible_on_preference_center: Optional[bool] = Field(
        alias="visibleOnPreferenceCenter"
    )
    short_form: Optional[bool] = Field(alias="shortForm")
    top_level_bucket_id: Optional[str] = Field(alias="topLevelBucketId")


GetWawEvent.update_forward_refs()
GetWawEventGetWawEvent.update_forward_refs()
GetWawEventGetWawEventCircuits.update_forward_refs()
GetWawEventGetWawEventPage.update_forward_refs()
GetWawEventGetWawEventPageEvent.update_forward_refs()
GetWawEventGetWawEventPageEventCircuits.update_forward_refs()
GetWawEventGetWawEventPageEventPage.update_forward_refs()
GetWawEventGetWawEventPageMinisite.update_forward_refs()
GetWawEventGetWawEventPageMinisiteLogo.update_forward_refs()
GetWawEventGetWawEventPageMinisiteFeatureImage.update_forward_refs()
GetWawEventGetWawEventPageMinisiteDefaultSponsors.update_forward_refs()
GetWawEventGetWawEventPageMinisiteSponsors.update_forward_refs()
GetWawEventGetWawEventPageContentModules.update_forward_refs()
GetWawEventGetWawEventPageContentModulesRelatedArticles.update_forward_refs()
GetWawEventGetWawEventPageContentModulesRelatedEvents.update_forward_refs()
GetWawEventGetWawEventPageContentModulesRelatedCompetitors.update_forward_refs()
GetWawEventGetWawEventPageContentModulesRelatedDiscipline.update_forward_refs()
GetWawEventGetWawEventPageContentModulesRelatedMedia.update_forward_refs()
GetWawEventGetWawEventPageContentModulesLifestyleLinks.update_forward_refs()
GetWawEventGetWawEventPageContentModulesFeatureLinks.update_forward_refs()
GetWawEventGetWawEventPageContentModulesMinisitePage.update_forward_refs()
GetWawEventGetWawEventPageContentModulesMinisite.update_forward_refs()
GetWawEventGetWawEventPageContentModulesLocations.update_forward_refs()
GetWawEventGetWawEventPageContentModulesVideos.update_forward_refs()
GetWawEventGetWawEventPageContentModulesBanners.update_forward_refs()
GetWawEventGetWawEventPageContentModulesSlides.update_forward_refs()
GetWawEventGetWawEventPageContentModulesSections.update_forward_refs()
GetWawEventGetWawEventPageContentModulesRelatedVideos.update_forward_refs()
GetWawEventGetWawEventPageContentModulesRelatedVideo.update_forward_refs()
GetWawEventGetWawEventPageCampaign.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class ResultsByAthlete(BaseModel):
    results_by_athlete: Optional["ResultsByAthleteResultsByAthlete"] = Field(
        alias="resultsByAthlete"
    )


class ResultsByAthleteResultsByAthlete(BaseModel):
    results: Optional[List[Optional["ResultsByAthleteResultsByAthleteResults"]]]
    parameters: Optional["ResultsByAthleteResultsByAthleteParameters"]


class ResultsByAthleteResultsByAthleteResults(BaseModel):
    athlete: Optional["ResultsByAthleteResultsByAthleteResultsAthlete"]
    competition: Optional[str]
    date: Optional[str]
    discipline: Optional[str]
    mark: Optional[str]
    match_type: Optional[str] = Field(alias="matchType")
    place: Optional[str]
    race: Optional[str]
    team: Optional[str]
    venue: Optional[str]


class ResultsByAthleteResultsByAthleteResultsAthlete(BaseModel):
    birth_date: Optional[str] = Field(alias="birthDate")
    country: Optional[str]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    id: Optional[int]
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")


class ResultsByAthleteResultsByAthleteParameters(BaseModel):
    athlete_ids: Optional[List[Optional[int]]] = Field(alias="athleteIds")
    country_of_residence: Optional[str] = Field(alias="countryOfResidence")
    limit: Optional[int]
    preferred_country: Optional[str] = Field(alias="preferredCountry")


ResultsByAthlete.update_forward_refs()
ResultsByAthleteResultsByAthlete.update_forward_refs()
ResultsByAthleteResultsByAthleteResults.update_forward_refs()
ResultsByAthleteResultsByAthleteResultsAthlete.update_forward_refs()
ResultsByAthleteResultsByAthleteParameters.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetWorldRankingsChanges(BaseModel):
    get_world_rankings_changes: Optional[
        "GetWorldRankingsChangesGetWorldRankingsChanges"
    ] = Field(alias="getWorldRankingsChanges")


class GetWorldRankingsChangesGetWorldRankingsChanges(BaseModel):
    module_title: Optional[str] = Field(alias="moduleTitle")
    module_subtitle: Optional[str] = Field(alias="moduleSubtitle")
    changes: Optional[
        List[Optional["GetWorldRankingsChangesGetWorldRankingsChangesChanges"]]
    ]


class GetWorldRankingsChangesGetWorldRankingsChangesChanges(BaseModel):
    ranking_calculation_id: Optional[int] = Field(alias="rankingCalculationId")
    place: Optional[int]
    previous_place: Optional[int] = Field(alias="previousPlace")
    improvement: Optional[str]
    event_name: Optional[str] = Field(alias="eventName")
    event_url_slug: Optional[str] = Field(alias="eventUrlSlug")
    score: Optional[int]
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_name: Optional[str] = Field(alias="competitorName")
    sex_code: Optional[str] = Field(alias="sexCode")
    country_code: Optional[str] = Field(alias="countryCode")


GetWorldRankingsChanges.update_forward_refs()
GetWorldRankingsChangesGetWorldRankingsChanges.update_forward_refs()
GetWorldRankingsChangesGetWorldRankingsChangesChanges.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetRankingGroups(BaseModel):
    get_ranking_groups: Optional[
        List[Optional["GetRankingGroupsGetRankingGroups"]]
    ] = Field(alias="getRankingGroups")


class GetRankingGroupsGetRankingGroups(BaseModel):
    event_group: Optional[str] = Field(alias="eventGroup")
    events: Optional[List[Optional["GetRankingGroupsGetRankingGroupsEvents"]]]


class GetRankingGroupsGetRankingGroupsEvents(BaseModel):
    name: Optional[str]
    display_name: Optional[str] = Field(alias="displayName")
    gender: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")


GetRankingGroups.update_forward_refs()
GetRankingGroupsGetRankingGroups.update_forward_refs()
GetRankingGroupsGetRankingGroupsEvents.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class CountriesByEventId(BaseModel):
    countries_by_event_id: Optional[
        List[Optional["CountriesByEventIdCountriesByEventId"]]
    ] = Field(alias="countriesByEventId")


class CountriesByEventIdCountriesByEventId(BaseModel):
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    id: Optional[str]
    country_name: Optional[str] = Field(alias="countryName")
    country_order: Optional[int] = Field(alias="countryOrder")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    area_order: Optional[int] = Field(alias="areaOrder")
    is_valid: Optional[bool] = Field(alias="isValid")
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    country_name_url_slug: Optional[str] = Field(alias="countryNameUrlSlug")


CountriesByEventId.update_forward_refs()
CountriesByEventIdCountriesByEventId.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetEventTeamStandingDetails(BaseModel):
    get_event_team_standing_details: Optional[
        List[Optional["GetEventTeamStandingDetailsGetEventTeamStandingDetails"]]
    ] = Field(alias="getEventTeamStandingDetails")


class GetEventTeamStandingDetailsGetEventTeamStandingDetails(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    team_standings_id: Optional[int] = Field(alias="teamStandingsId")
    team_standing_detail_order: Optional[int] = Field(alias="teamStandingDetailOrder")
    event_id: Optional[int] = Field(alias="eventId")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    rank: Optional[int]
    result_rank: Optional[int] = Field(alias="resultRank")
    result_mark: Optional[str] = Field(alias="resultMark")
    record: Optional[str]
    standing_points: Optional[int] = Field(alias="standingPoints")
    team_id: Optional[int] = Field(alias="teamId")
    team_name: Optional[str] = Field(alias="teamName")
    team_country_code: Optional[str] = Field(alias="teamCountryCode")
    standing_mark: Optional[int] = Field(alias="standingMark")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    team_id__w_a: Optional[int] = Field(alias="teamId_WA")
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor: Optional[
        "GetEventTeamStandingDetailsGetEventTeamStandingDetailsCompetitor"
    ]
    discipline: Optional[
        "GetEventTeamStandingDetailsGetEventTeamStandingDetailsDiscipline"
    ]


class GetEventTeamStandingDetailsGetEventTeamStandingDetailsCompetitor(BaseModel):
    id: Optional[int] = Field(alias="_id")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    information: Optional[str]
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    birth_date: Optional[Any] = Field(alias="birthDate")
    birth_date_str: Optional[str] = Field(alias="birthDateStr")
    url_slug: Optional[str] = Field(alias="urlSlug")
    representative_type_code: Optional[str] = Field(alias="representativeTypeCode")
    representative_id: Optional[int] = Field(alias="representativeId")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    name: Optional[str]
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    sex_name_url_slug: Optional[str] = Field(alias="sexNameUrlSlug")
    friendly_name: Optional[str] = Field(alias="friendlyName")
    friendly_name_letter: Optional[str] = Field(alias="friendlyNameLetter")
    friendly_name_first3_letter: Optional[str] = Field(alias="friendlyNameFirst3Letter")


class GetEventTeamStandingDetailsGetEventTeamStandingDetailsDiscipline(BaseModel):
    id: Optional[str] = Field(alias="_id")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    name: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    type_name: Optional[str] = Field(alias="typeName")
    type_order: Optional[int] = Field(alias="typeOrder")
    order: Optional[int]
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_road: Optional[bool] = Field(alias="isRoad")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")


GetEventTeamStandingDetails.update_forward_refs()
GetEventTeamStandingDetailsGetEventTeamStandingDetails.update_forward_refs()
GetEventTeamStandingDetailsGetEventTeamStandingDetailsCompetitor.update_forward_refs()
GetEventTeamStandingDetailsGetEventTeamStandingDetailsDiscipline.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetLivePhaseSummary(BaseModel):
    get_live_phase_summary: Optional[
        List[Optional["GetLivePhaseSummaryGetLivePhaseSummary"]]
    ] = Field(alias="getLivePhaseSummary")


class GetLivePhaseSummaryGetLivePhaseSummary(BaseModel):
    id: str
    phase_summary_id: Optional[int] = Field(alias="phaseSummaryId")
    phase_id: Optional[int] = Field(alias="phaseId")
    unit_id: Optional[int] = Field(alias="unitId")
    unit_name: Optional[str] = Field(alias="unitName")
    unit_type: Optional[str] = Field(alias="unitType")
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_team_name: Optional[str] = Field(alias="competitorTeamName")
    competitor_forename: Optional[str] = Field(alias="competitorForename")
    competitor_surname: Optional[str] = Field(alias="competitorSurname")
    competitor_country_name: Optional[str] = Field(alias="competitorCountryName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    competitor_sex: Optional[str] = Field(alias="competitorSex")
    competitor_type: Optional[str] = Field(alias="competitorType")
    bib: Optional[str]
    rank: Optional[str]
    mark: Optional[str]
    wind: Optional[str]
    result_wind: Optional[str] = Field(alias="resultWind")
    record: Optional[str]
    qualified: Optional[str]
    combined_points: Optional[str] = Field(alias="combinedPoints")
    updated_on: Optional[str] = Field(alias="updatedOn")
    result_rank: Optional[str] = Field(alias="resultRank")
    phase_summary_order: Optional[int] = Field(alias="phaseSummaryOrder")
    provisional_qualifier: Optional[bool] = Field(alias="provisionalQualifier")
    event_store_id: Optional[str] = Field(alias="eventStoreId")
    competition_id: Optional[int] = Field(alias="competitionId")
    reaction_time: Optional[str] = Field(alias="reactionTime")
    phase_summary_milliseconds: Optional[str] = Field(alias="phaseSummaryMilliseconds")


GetLivePhaseSummary.update_forward_refs()
GetLivePhaseSummaryGetLivePhaseSummary.update_forward_refs()
